@@ -1,16 +1,17 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "ភារកិច្ច",
     "Important" : "សំខាន់",
     "Today" : "ថ្ងៃ​នេះ",
     "Week" : "សប្ដាហ៍",
     "All" : "ទាំងអស់",
-    "Delete" : "លុប",
+    "Tasks" : "ភារកិច្ច",
+    "can edit" : "អាច​កែប្រែ",
     "Cancel" : "បោះបង់",
-    "Default" : "លំនាំ​ដើម",
+    "Save" : "រក្សាទុក",
     "Edit" : "កែប្រែ",
     "Download" : "ទាញយក",
-    "Save" : "រក្សាទុក"
+    "Delete" : "លុប",
+    "Unshare" : "លែង​ចែក​រំលែក"
 },
 "nplurals=1; plural=0;");
