@@ -1,29 +1,33 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Tâchen",
     "Important" : "Wichteg",
     "Today" : "Haut",
     "Week" : "Woch",
     "All" : "All",
     "Current" : "Aktuell",
     "Completed" : "Erfëllt",
-    "Delete" : "Läschen",
+    "Tasks" : "Tâchen",
+    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
+    "can edit" : "kann änneren",
+    "New List" : "Nei Lëscht",
     "Cancel" : "Ofbriechen",
-    "Default" : "Standard",
+    "Save" : "Späicheren",
+    "An empty name is not allowed." : "En eidelen Numm ass net erlaabt.",
+    "Edit" : "Änneren",
+    "Download" : "Eroflueden",
+    "Delete" : "Läschen",
+    "Unshare" : "Net méi deelen",
+    "Hidden" : "Verstoppt",
+    "Visible" : "Visibel",
+    "Automatic" : "Automatesch",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n erfëllt Aufgab","%n erfëllten Aufgaben"],
     "Tomorrow" : "Muer",
     "Set start date" : "Setz en Ufanks Datum fest",
     "Set due date" : "Datum setzen bis wéini et fälleg ass",
     "Task not found!" : "Tâche konnt net fonnt ginn!",
-    "Edit" : "Änneren",
-    "Download" : "Eroflueden",
-    "Save" : "Späicheren",
-    "New List" : "Nei Lëscht",
-    "An empty name is not allowed." : "En eidelen Numm ass net erlaabt.",
-    "Settings" : "Astellungen",
-    "Hidden" : "Verstoppt",
-    "Visible" : "Visibel",
-    "Automatic" : "Automatesch"
+    "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
+    "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
+    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement"
 },
 "nplurals=2; plural=(n != 1);");
