@@ -1,17 +1,21 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Oppgåver",
     "Important" : "Viktig",
     "Today" : "I dag",
     "Week" : "Veke",
     "All" : "Alle",
-    "Delete" : "Slett",
+    "Tasks" : "Oppgåver",
+    "can edit" : "kan endra",
     "Cancel" : "Avbryt",
-    "Default" : "Standard",
+    "Save" : "Lagra",
     "Edit" : "Endra",
     "Download" : "Last ned",
-    "Save" : "Lagra",
-    "Settings" : "Innstillingar"
+    "Delete" : "Slett",
+    "Unshare" : "Fjern deling",
+    "Last modified" : "Siste endra",
+    "When shared show full event" : "Når delt, vis heile hendinga",
+    "When shared show only busy" : "Når delt, vis berre oppteken",
+    "When shared hide this event" : "Når delt, gøym denne hendinga"
 },
 "nplurals=2; plural=(n != 1);");
